@@ -16,18 +16,14 @@
 #'
 #' @export
 #'
-#' @note
-#' This function **requires internet connectivity** as it checks the
-#' [NCAA website](https://stats.ncaa.org) for information.
+#' @inherit request_url note
 #'
 #' @family search functions
 #'
 #' @examplesIf interactive()
 #' find_team_id(team = "Nebraska", year = 2024)
 #' find_team_id(team = "UCLA", year = 2023, sport = "MVB")
-find_team_id <- function(team = NULL,
-                         year = NULL,
-                         sport = "WVB") {
+find_team_id <- function(team = NULL, year = NULL, sport = "WVB") {
   # check inputs
   team_df <- check_sport(sport, vb_only = TRUE)
   check_team_name(team, teams = team_df)
